import Vue from 'vue'
import Router from 'vue-router'
import DashboardLayout from '@/layout/DashboardLayout'
import AuthLayout from '@/layout/AuthLayout'
import store from "./store";
Vue.use(Router);

const ifNotAuthenticated = (to , from, next) => {
  if(!store.getters.isAuthenticated) {
    next();
    return;
  }

  next('/');
}

const ifAuthenticated = (to, from, next) => {
  if(store.getters.isAuthenticated) {
    next();
    return;
  }

  next("/login");
}

export default new Router({
  linkExactActiveClass: 'active',
  mode: "history",
  routes: [
    {
      path: '/',
      redirect: 'subdomains',
      component: DashboardLayout,
      beforeEnter: ifAuthenticated,
      children: [
        {
          path: '/subdomains',
          name: 'subdomains',
          // route level code-splitting
          // this generates a separate chunk (about.[hash].js) for this route
          // which is lazy-loaded when the route is visited.
          component: () => import(/* webpackChunkName: "demo" */ './views/Subdomains.vue')
        },
        {
          path: '/projects',
          name: 'projects',
          // route level code-splitting
          // this generates a separate chunk (about.[hash].js) for this route
          // which is lazy-loaded when the route is visited.
          component: () => import(/* webpackChunkName: "demo" */ './views/Projects.vue')
        },
        {
          path: '/icons',
          name: 'icons',
          component: () => import(/* webpackChunkName: "demo" */ './views/Icons.vue')
        },
        {
          path: '/profile',
          name: 'profile',
          component: () => import(/* webpackChunkName: "demo" */ './views/UserProfile.vue')
        },
        {
          path: '/maps',
          name: 'maps',
          component: () => import(/* webpackChunkName: "demo" */ './views/Maps.vue')
        },
        {
          path: '/tables',
          name: 'tables',
          component: () => import(/* webpackChunkName: "demo" */ './views/Tables.vue')
        }
      ]
    },
    {
      path: '/login',
      redirect: 'login',
      component: AuthLayout,
      children: [
        {
          path: '/login',
          name: 'login',
          component: () => import(/* webpackChunkName: "demo" */ './views/Login.vue')
        },
        {
          path: '/register',
          name: 'register',
          component: () => import(/* webpackChunkName: "demo" */ './views/Register.vue')
        }
      ]
    }
  ]
})
